@@ -1,22 +1,11 @@
 /*
- Copyright (C) 2001 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2001 Ellis Whitehead <ellis@kde.org>
 
- Win32 port:
- Copyright (C) 2004 Jarosław Staniek <staniek@kde.org>
+    Win32 port:
+    SPDX-FileCopyrightText: 2004 Jarosław Staniek <staniek@kde.org>
 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Lesser General Public
- License as published by the Free Software Foundation; either
- version 2.1 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public
- License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "kkeyserver.h"
 
@@ -42,10 +31,10 @@ struct ModInfo {
 // no need for I18N_NOOP2's here.
 #define KEYCTXT "keyboard-key-name"
 static ModInfo g_rgModInfo[4] = {
-    { Qt::SHIFT,   "Shift", nullptr },
-    { Qt::CTRL,    "Ctrl", nullptr },
-    { Qt::ALT,     "Alt", nullptr },
-    { Qt::META,    "Meta", nullptr }
+    {Qt::SHIFT, "Shift", nullptr},
+    {Qt::CTRL, "Ctrl", nullptr},
+    {Qt::ALT, "Alt", nullptr},
+    {Qt::META, "Meta", nullptr},
 };
 
 //---------------------------------------------------------------------
@@ -62,7 +51,6 @@ static void intializeKKeyLabels()
     g_rgModInfo[3].sLabel = new QString(QCoreApplication::translate("KKeyServer", (g_rgModInfo[3].psName), KEYCTXT));
     g_bMacLabels = (*g_rgModInfo[2].sLabel == QLatin1String("Command"));
     g_bInitializedKKeyLabels = true;
-
 }
 
 //---------------------------------------------------------------------
@@ -81,9 +69,7 @@ static QString modToString(uint mod, bool bUserSpace)
             if (!s.isEmpty()) {
                 s += QLatin1Char('+');
             }
-            s += (bUserSpace)
-                 ? *g_rgModInfo[i].sLabel
-                 : QLatin1String(g_rgModInfo[i].psName);
+            s += (bUserSpace) ? *g_rgModInfo[i].sLabel : QLatin1String(g_rgModInfo[i].psName);
         }
     }
     return s;
@@ -117,7 +103,8 @@ bool isShiftAsModifierAllowed(int keyQt)
         return true;
     }
 
-    if (QChar(keyQt).isLetter()) {
+    // Returns false if not a unicode code point
+    if (QChar::isLetter(keyQt)) {
         return true;
     }
 
