@@ -9,7 +9,6 @@
 #define KXUTILS_H
 
 #include <QPixmap>
-#include <QScopedPointer>
 #include <config-kwindowsystem.h>
 
 #if KWINDOWSYSTEM_HAVE_X11
@@ -23,15 +22,6 @@ struct xcb_connection_t;
  */
 namespace KXUtils
 {
-template<typename T>
-class ScopedCPointer : public QScopedPointer<T, QScopedPointerPodDeleter>
-{
-public:
-    ScopedCPointer(T *p = nullptr)
-        : QScopedPointer<T, QScopedPointerPodDeleter>(p)
-    {
-    }
-};
 
 /**
  * Creates a QPixmap that contains a copy of the pixmap given by the X handle @p pixmap
